Test Coverage -- lots of new pieces of actions.c
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index b80104d8a9bb044e06f61ee950d90bb52c11021a..8f91e44716ad0b6b95efeb6681fa0648d7399631 100644 (file)
--- a/score.c
+++ b/score.c
@@ -50,14 +50,14 @@ long score(enum termination mode)
         }
     }
 
/*  Now look at how he finished and how far he got.  MAXDIE and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still
      *  indicates whether he reached the endgame.  And if he got as far as
      *  "cave closed" (indicated by "game.closed"), then bonus is zero for
      *  mundane exits or 133, 134, 135 if he blew it (so to speak). */
-    score += (MAXDIE - game.numdie) * 10;
-    mxscor += MAXDIE * 10;
+    score += (maximum_deaths - game.numdie) * 10;
+    mxscor += maximum_deaths * 10;
     if (mode == endgame)
         score += 4;
     mxscor += 4;
@@ -78,7 +78,7 @@ long score(enum termination mode)
     mxscor += 45;
 
     /* Did he come to Witt's End as he should? */
-    if (game.place[MAGZIN] == LOC_WITTSEND)
+    if (game.place[MAGAZINE] == LOC_WITTSEND)
         score += 1;
     mxscor += 1;
 
@@ -89,7 +89,7 @@ long score(enum termination mode)
     /* Deduct for hints/turns/saves. Hints < 4 are special; see database desc. */
     for (long i = 1; i <= HNTMAX; i++) {
         if (game.hinted[i])
-            score = score - HINTS[i][2];
+            score = score - hints[i-1].penalty;
     }
     if (game.novice)
         score -= 5;
@@ -120,9 +120,9 @@ void terminate(enum termination mode)
     SETPRM(3, game.turns, game.turns);
     RSPEAK(TOTAL_SCORE);
     for (long i = 1; i <= (long)CLSSES; i++) {
-        if (CVAL[i] >= points) {
-            speak(class_messages[i]);
-            i = CVAL[i] + 1 - points;
+        if (classes[i].threshold >= points) {
+            speak(classes[i].message);
+            i = classes[i].threshold + 1 - points;
             SETPRM(1, i, i);
             RSPEAK(NEXT_HIGHER);
             exit(0);
@@ -50,14 +50,14 @@ long score(enum termination mode)
     }
 
-    /*  Now look at how he finished and how far he got.  MAXDIE and
+    /*  Now look at how he finished and how far he got.  maximum_deaths and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still